==> sb_h5-v04.02.301.zip: sb_h5-v04.02.301/app/service/storage.js <==
'use strict';

const Service = require('egg').Service;

class StorageService extends Service {
  constructor(ctx) {
    super(ctx);
    const { config } = this;
    const { storageAPI } = config;
    this.baseURL = storageAPI.host;
    this.writeUrl = storageAPI.writeUrl;
    this.readUrl = storageAPI.readUrl;
    this.writeType = storageAPI.writeType;
    this.readDataKey = storageAPI.readDataKey;
  }

  _request(url, opts) {
    const { ctx, baseURL } = this;
    url = `${baseURL}${url}`;
    opts = {
      charset: 'utf-8',
      timeout: ['30s', '30s'],
      dataType: 'json',
      ...opts,
    };
    return ctx.curl(url, opts);
  }


  async write(data) {
    const { writeUrl, writeType, ctx } = this;
    const result = await this._request(writeUrl, {
      method: 'post',
      data: { ...data, serviceType: writeType },
      contentType: 'json',
    });

    ctx.logger.info(`【Storage】write url:${writeUrl} params`, { ...data, serviceType: writeType }, 'result:', result.data);
    if (!(result.data.code !== '0' || result.data.code !== 0)) {
      throw new Error('存储数据出错');
    }
    return;
  }

  async read(orderId, appKey) {
    const { readUrl, readDataKey, ctx } = this;
    const result = await this._request(`${readUrl}${orderId}`, {
      method: 'get',
      contentType: 'json',
    });
    ctx.logger.info(`【Storage】read url:${readUrl}${orderId}`);

    if (result && result.data && result.data.code !== 0) {
      ctx.logger.error(`storageAPI read ${readUrl}${orderId}`, JSON.stringify(result.data));
      ctx.throw(400, { message: result.data.msg });
    }
    // 操作cus_data表记录拉取数据
    await ctx.model.Cusdata.create({
      appKey,
      orderId,
      type: 'sbH5',
    });
    await ctx.nodemodel.Cusdata.create({
      appkey: appKey,
      orderSn: orderId,
      type: 'sbH5',
    });
    return result.data.data[readDataKey];
  }
}

module.exports = StorageService;

==> sb_h5-v09.10.002.zip: sb_h5-v09.10.002/app/service/storage.js <==
'use strict';

const Service = require('egg').Service;

class StorageService extends Service {
  constructor(ctx) {
    super(ctx);
    const { config } = this;
    const { storageAPI } = config;
    this.baseURL = storageAPI.host;
    this.writeUrl = storageAPI.writeUrl;
    this.readUrl = storageAPI.readUrl;
    this.writeType = storageAPI.writeType;
    this.readDataKey = storageAPI.readDataKey;
  }

  _request(url, opts) {
    const { ctx, baseURL } = this;
    url = `${baseURL}${url}`;
    opts = {
      charset: 'utf-8',
      timeout: ['30s', '30s'],
      dataType: 'json',
      ...opts,
    };
    return ctx.curl(url, opts);
  }


  async write(data) {
    const { writeUrl, writeType, ctx } = this;
    const result = await this._request(writeUrl, {
      method: 'post',
      data: { ...data, serviceType: writeType },
      contentType: 'json',
    });

    ctx.logger.info(`【Storage】write url:${writeUrl} params`, { ...data, serviceType: writeType }, 'result:', result.data);
    if (result.data.code !== '0') {
      throw new Error('存储数据出错');
    }
    return;
  }

  async read(orderId, appKey) {
    const { readUrl, readDataKey, ctx } = this;
    const result = await this._request(`${readUrl}/${orderId}`, {
      method: 'get',
      contentType: 'json',
    });
    ctx.logger.info(`【Storage】read url:${readUrl}/${orderId}`);

    if (result && result.data && result.data.code !== 0) {
      ctx.logger.error(`storageAPI read ${readUrl}/${orderId}`, JSON.stringify(result.data));
      ctx.throw(400, { message: result.data.msg });
    }
    // 操作cus_data表记录拉取数据
    await ctx.model.Cusdata.create({
      appKey,
      orderId,
      type: 'sbH5',
    });
    await ctx.nodemodel.Cusdata.create({
      appkey: appKey,
      orderSn: orderId,
      type: 'sbH5',
    });
    return result.data.data[readDataKey];
  }
}

module.exports = StorageService;
